==> vue-collapse-item-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/collapse-item/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import CollapseTransition from "@dftvue2-opentiny/vue-collapse-transition";
import { IconArrowBottom } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "titleRight", "name", "disabled"]),
  components: {
    CollapseTransition,
    IconArrowBottom: IconArrowBottom()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "border-b-0.5 sm:border-b border-solid border-color-border-disabled last:border-0"
  }, [_c("div", {
    attrs: {
      "role": "tab",
      "aria-expanded": _vm.state.isActive,
      "aria-controls": "tiny-collapse-content-" + _vm.state.id,
      "aria-describedby": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "flex relative items-center h-12 sm:h-14 py-0 sm:pr-0 pl-4 sm:pl-4 pr-14 text-sm font-bold justify-between whitespace-nowrap",
    class: _vm.disabled ? "text-color-text-disabled" : "text-color-text-primary [&:has(.peer:hover)_[role=title]]:text-color-brand",
    attrs: {
      "id": "tiny-collapse-head-" + _vm.state.id,
      "tabindex": _vm.disabled ? void 0 : 0
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"]) && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
          return null;
        $event.stopPropagation();
        return _vm.handleEnterClick.apply(null, arguments);
      },
      "focus": _vm.handleFocus,
      "blur": function blur($event) {
        _vm.state.focusing = false;
      }
    }
  }, [_c("div", {
    staticClass: "whitespace-nowrap overflow-hidden overflow-ellipsis inline-block peer",
    class: [_vm.disabled ? "cursor-not-allowed" : "cursor-pointer hover:text-color-brand"],
    attrs: {
      "role": "title"
    },
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("title", function() {
    return [_vm._v(" " + _vm._s(_vm.title))];
  })], 2), _c("div", {
    staticClass: "text-xs font-normal"
  }, [_vm._t("title-right", function() {
    return [_vm._v(_vm._s(_vm.titleRight))];
  })], 2), _c("div", {
    staticClass: "absolute sm:left-0 right-2 text-xs mr-1 w-3 peer",
    class: [_vm.disabled ? "fill-color-text-disabled  cursor-not-allowed" : "fill-color-icon-secondary cursor-pointer peer-hover:fill-color-brand hover:fill-color-brand"],
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("icon", function() {
    return [_c("icon-arrow-bottom", {
      staticClass: "w-2.5 h-2.5 sm:w-3 sm:h-3 transition-transform duration-300",
      class: [_vm.state.isActive ? "sm:rotate-0 rotate-180" : "sm:-rotate-90 rotate-0"]
    })];
  }, {
    "active": _vm.state.isActive,
    "disabled": _vm.disabled
  })], 2)])]), _c("collapse-transition", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    staticClass: "will-change-[height] bg-color-bg-1 overflow-hidden box-border",
    attrs: {
      "role": "tabpanel",
      "aria-hidden": !_vm.state.isActive,
      "aria-labelledby": "tiny-collapse-head-" + _vm.state.id,
      "id": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "pb-6 pt-0 px-4 sm:pt-0 sm:pr-0 sm:pl-4 sm:pb-4 text-xs text-color-text-primary leading-relaxed"
  }, [_vm._t("default")], 2)])])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-collapse-item-2.22.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/collapse-item/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import CollapseTransition from '@opentinyvue/vue-collapse-transition';
import { IconArrowBottom } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "titleRight", "name", "disabled"]),
  components: {
    CollapseTransition,
    IconArrowBottom: IconArrowBottom()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "border-b-0.5 sm:border-b border-solid border-color-border-separator last:border-0",
    attrs: {
      "data-tag": "tiny-collapse-item"
    }
  }, [_c("div", {
    attrs: {
      "role": "tab",
      "data-tag": "tiny-collapse-item-tab",
      "aria-expanded": _vm.state.isActive,
      "aria-controls": "tiny-collapse-content-" + _vm.state.id,
      "aria-describedby": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "flex relative items-center h-12 sm:h-10 py-0 sm:pr-0 pl-4 pr-10 text-sm font-bold justify-between whitespace-nowrap",
    class: _vm.disabled ? "text-color-text-disabled" : "text-color-text-primary sm:[&:has(.peer:hover)_[role=title]]:text-color-brand",
    attrs: {
      "data-tag": "tiny-collapse-item-body",
      "id": "tiny-collapse-head-" + _vm.state.id,
      "tabindex": _vm.disabled ? void 0 : 0
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"]) && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        $event.stopPropagation();
        return _vm.handleEnterClick.apply(null, arguments);
      },
      "focus": _vm.handleFocus,
      "blur": function blur($event) {
        _vm.state.focusing = false;
      }
    }
  }, [_c("div", {
    staticClass: "whitespace-nowrap overflow-hidden overflow-ellipsis inline-block peer",
    class: [_vm.disabled ? "cursor-not-allowed" : "cursor-pointer sm:hover:text-color-brand"],
    attrs: {
      "data-tag": "tiny-collapse-item-title",
      "role": "title"
    },
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("title", function() {
    return [_vm._v(" " + _vm._s(_vm.title))];
  })], 2), _c("div", {
    staticClass: "text-xs font-normal",
    attrs: {
      "data-tag": "tiny-collapse-item-titleright"
    }
  }, [_vm._t("title-right", function() {
    return [_vm._v(_vm._s(_vm.titleRight))];
  })], 2), _c("div", {
    staticClass: "absolute sm:left-0 right-3.5 text-xs mr-1 w-3 peer",
    class: [_vm.disabled ? "fill-color-text-disabled  cursor-not-allowed" : "fill-color-icon-secondary cursor-pointer sm:peer-hover:fill-color-brand sm:hover:fill-color-brand"],
    attrs: {
      "data-tag": "tiny-collapse-item-icon"
    },
    on: {
      "click": _vm.handleHeaderClick
    }
  }, [_vm._t("icon", function() {
    return [_c("icon-arrow-bottom", {
      class: [_vm.state.isActive ? "sm:rotate-0 rotate-180" : "sm:-rotate-90 rotate-0"],
      attrs: {
        "custom-class": "w-2.5 h-2.5 sm:w-3 sm:h-3 transition-transform duration-300"
      }
    })];
  }, {
    "active": _vm.state.isActive,
    "disabled": _vm.disabled
  })], 2)])]), _c("collapse-transition", [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.isActive,
      expression: "state.isActive"
    }],
    staticClass: "will-change-[height] bg-color-bg-1 overflow-hidden box-border",
    attrs: {
      "data-tag": "tiny-collapse-item-active",
      "role": "tabpanel",
      "aria-hidden": !_vm.state.isActive,
      "aria-labelledby": "tiny-collapse-head-" + _vm.state.id,
      "id": "tiny-collapse-content-" + _vm.state.id
    }
  }, [_c("div", {
    staticClass: "pb-6 pt-0 px-4 sm:pt-0 sm:pr-0 sm:pl-4 sm:pb-4 text-xs text-color-text-primary leading-relaxed"
  }, [_vm._t("default")], 2)])])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
